@@ -15,8 +15,7 @@ def test_auto_mapper_amount_typed(spark_session: SparkSession) -> None:
         [
             (1, 'Qureshi', 'Imran', "54.45"),
             (2, 'Vidal', 'Michael', "67.67"),
-        ],
-        ['member_id', 'last_name', 'first_name', "my_age"]
+        ], ['member_id', 'last_name', 'first_name', "my_age"]
     ).createOrReplaceTempView("patients")
 
     source_df: DataFrame = spark_session.table("patients")
@@ -27,22 +26,17 @@ def test_auto_mapper_amount_typed(spark_session: SparkSession) -> None:
 
     # Act
     mapper = AutoMapper(
-        view="members",
-        source_view="patients",
-        keys=["member_id"]
-    ).columns(
-        age=A.amount(
-            A.column("my_age")
-        )
-    )
+        view="members", source_view="patients", keys=["member_id"]
+    ).columns(age=A.amount(A.column("my_age")))
 
     assert isinstance(mapper, AutoMapper)
-    sql_expressions: Dict[str, Column] = mapper.get_column_specs(source_df=source_df)
+    sql_expressions: Dict[str, Column] = mapper.get_column_specs(
+        source_df=source_df
+    )
     for column_name, sql_expression in sql_expressions.items():
         print(f"{column_name}: {sql_expression}")
 
-    assert str(sql_expressions["age"]) == str(
-        col("my_age").alias("age"))
+    assert str(sql_expressions["age"]) == str(col("my_age").alias("age"))
 
     result_df: DataFrame = mapper.transform(df=df)
 
@@ -50,7 +44,11 @@ def test_auto_mapper_amount_typed(spark_session: SparkSession) -> None:
     result_df.printSchema()
     result_df.show()
 
-    assert approx(result_df.where("member_id == 1").select("age").collect()[0][0]) == approx(54.45)
-    assert approx(result_df.where("member_id == 2").select("age").collect()[0][0]) == approx(67.67)
+    assert approx(
+        result_df.where("member_id == 1").select("age").collect()[0][0]
+    ) == approx(54.45)
+    assert approx(
+        result_df.where("member_id == 2").select("age").collect()[0][0]
+    ) == approx(67.67)
 
     assert dict(result_df.dtypes)["age"] == "float"
