@@ -6,6 +6,7 @@ from pyspark.sql.functions import array, struct
 from pyspark.sql.functions import lit
 
 from spark_auto_mapper.automappers.automapper import AutoMapper
+from spark_auto_mapper.data_types.list import AutoMapperList
 from spark_auto_mapper.helpers.automapper_helpers import AutoMapperHelpers as A
 
 
@@ -28,7 +29,7 @@ def test_auto_mapper_array_single_item_with_mapper(
     # Act
     mapper = AutoMapper(
         view="members", source_view="patients", keys=["member_id"]
-    ).columns(dst2=A.list(A.complex(addr="address1")))
+    ).columns(dst2=AutoMapperList([A.complex(addr="address1")]))
 
     assert isinstance(mapper, AutoMapper)
     sql_expressions: Dict[str, Column] = mapper.get_column_specs(
