@@ -8,14 +8,15 @@ from spark_auto_mapper.automappers.automapper import AutoMapper
 from spark_auto_mapper.helpers.automapper_helpers import AutoMapperHelpers as A
 
 
-def test_auto_mapper_with_column_expression(spark_session: SparkSession) -> None:
+def test_auto_mapper_with_column_expression(
+    spark_session: SparkSession
+) -> None:
     # Arrange
     spark_session.createDataFrame(
         [
             (1, 'Qureshi', 'Imran'),
             (2, 'Vidal', 'Michael'),
-        ],
-        ['member_id', 'last_name', 'first_name']
+        ], ['member_id', 'last_name', 'first_name']
     ).createOrReplaceTempView("patients")
 
     source_df: DataFrame = spark_session.table("patients")
@@ -25,19 +26,18 @@ def test_auto_mapper_with_column_expression(spark_session: SparkSession) -> None
 
     # Act
     mapper = AutoMapper(
-        view="members",
-        source_view="patients",
-        keys=["member_id"]
-    ).columns(
-        lname=A.expression("SUBSTRING(last_name,1,3)")
-    )
+        view="members", source_view="patients", keys=["member_id"]
+    ).columns(lname=A.expression("SUBSTRING(last_name,1,3)"))
 
     assert isinstance(mapper, AutoMapper)
-    sql_expressions: Dict[str, Column] = mapper.get_column_specs(source_df=source_df)
+    sql_expressions: Dict[str, Column] = mapper.get_column_specs(
+        source_df=source_df
+    )
     for column_name, sql_expression in sql_expressions.items():
         print(f"{column_name}: {sql_expression}")
 
-    assert str(sql_expressions["lname"]) == str(expr("SUBSTRING(last_name,1,3)").alias("lname"))
+    assert str(sql_expressions["lname"]
+               ) == str(expr("SUBSTRING(last_name,1,3)").alias("lname"))
 
     result_df: DataFrame = mapper.transform(df=df)
 
@@ -45,5 +45,7 @@ def test_auto_mapper_with_column_expression(spark_session: SparkSession) -> None
     result_df.printSchema()
     result_df.show()
 
-    assert result_df.where("member_id == 1").select("lname").collect()[0][0] == "Qur"
-    assert result_df.where("member_id == 2").select("lname").collect()[0][0] == "Vid"
+    assert result_df.where("member_id == 1").select("lname"
+                                                    ).collect()[0][0] == "Qur"
+    assert result_df.where("member_id == 2").select("lname"
+                                                    ).collect()[0][0] == "Vid"
